@@ -13,7 +13,7 @@ use English '-no_match_vars';
 use 5.006;
 
 # Declare package version
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 # Patterns to match elements of the LRC file; these are somewhat tolerant
 our %RE = (
@@ -46,7 +46,7 @@ our %RE = (
             (\d+)         # Minutes, capture
             :             # Colon
             (             # Seconds group, capture
-                \d{2}         # Whole seconds
+                \d{1,2}       # Whole seconds
                 (?:           # Group for fractional seconds
                     [.]           # Period
                     \d+           # At least one digit
@@ -272,7 +272,7 @@ Music::Lyrics::LRC - Manipulate LRC karaoke timed lyrics files
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =head1 DESCRIPTION
 
